@@ -3,7 +3,7 @@ BEGIN {
   $POE::Component::IRC::Plugin::RTorrentStatus::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $POE::Component::IRC::Plugin::RTorrentStatus::VERSION = '0.08';
+  $POE::Component::IRC::Plugin::RTorrentStatus::VERSION = '0.09';
 }
 
 use strict;
@@ -14,7 +14,7 @@ use DateTime::Format::Human::Duration;
 use File::Basename qw(fileparse);
 use Format::Human::Bytes;
 use POE::Component::IRC::Plugin qw(PCI_EAT_NONE);
-use POE::Component::IRC::Common qw(NORMAL DARK_GREEN DARK_BLUE ORANGE TEAL BROWN);
+use POE::Component::IRC::Common qw(NORMAL DARK_GREEN DARK_BLUE ORANGE TEAL BROWN PURPLE MAGENTA);
 use POE::Component::IRC::Plugin::FollowTail;
 
 sub new {
@@ -110,7 +110,7 @@ sub _finished_torrent {
     my $duration = _duration($hash_started, $hash_done);
 
     my $msg = $self->{Color}
-        ? DARK_GREEN.'Hashed: '.ORANGE.$name.NORMAL." in $duration"
+        ? PURPLE.'Hashed: '.ORANGE.$name.NORMAL." in $duration"
         : "Hashed: $name in $duration";
 
     if ($rars > 0) {
@@ -129,7 +129,7 @@ sub _unrar_torrent {
     my $info = defined $file ? $file : "$rars $archives";
 
     my $msg = $self->{Color}
-        ? TEAL.'Unrared: '.ORANGE.$name.NORMAL." in $duration ($info)"
+        ? MAGENTA.'Unrared: '.ORANGE.$name.NORMAL." in $duration ($info)"
         : "Unrared: $name in $duration ($info)";
 
     return $msg;
